@@ -15,30 +15,32 @@ from pandas_datareader._utils import (RemoteDataError, SymbolWarning,
 
 
 class _BaseReader(object):
-
     """
-
     Parameters
     ----------
-        sym : string with a single Single stock symbol (ticker).
-        start : string, (defaults to '1/1/2010')
-                Starting date, timestamp. Parses many different kind of date
-                representations (e.g., 'JAN-01-2010', '1/1/10', 'Jan, 1, 1980')
-        end : string, (defaults to today)
-                Ending date, timestamp. Same format as starting date.
-        retry_count : int, default 3
-                Number of times to retry query request.
-        pause : float, default 0.1
-                Time, in seconds, of the pause between retries.
-        session : Session, default None
-                requests.sessions.Session instance to be used
+    symbols : {str, List[str]}
+        String symbol of like of symbols
+    start : string, (defaults to '1/1/2010')
+        Starting date, timestamp. Parses many different kind of date
+        representations (e.g., 'JAN-01-2010', '1/1/10', 'Jan, 1, 1980')
+    end : string, (defaults to today)
+        Ending date, timestamp. Same format as starting date.
+    retry_count : int, default 3
+        Number of times to retry query request.
+    pause : float, default 0.1
+        Time, in seconds, of the pause between retries.
+    session : Session, default None
+        requests.sessions.Session instance to be used
+    freq : {str, None}
+        Frequency to use in select readers
     """
 
     _chunk_size = 1024 * 1024
     _format = 'string'
 
-    def __init__(self, symbols, start=None, end=None,
-                 retry_count=3, pause=0.1, timeout=30, session=None):
+    def __init__(self, symbols, start=None, end=None,  retry_count=3,
+                 pause=0.1, timeout=30, session=None, freq=None):
+
         self.symbols = symbols
 
         start, end = _sanitize_dates(start, end)
@@ -52,22 +54,25 @@ class _BaseReader(object):
         self.timeout = timeout
         self.pause_multiplier = 1
         self.session = _init_session(session, retry_count)
+        self.freq = freq
 
     def close(self):
-        """ close my session """
+        """Close network session"""
         self.session.close()
 
     @property
     def url(self):
+        """API URL"""
         # must be overridden in subclass
         raise NotImplementedError
 
     @property
     def params(self):
+        """Parameters to use in API calls"""
         return None
 
     def read(self):
-        """ read data """
+        """Read data from connector"""
         try:
             return self._read_one_data(self.url, self.params)
         finally:
@@ -120,6 +125,7 @@ class _BaseReader(object):
 
         # initial attempt + retry
         pause = self.pause
+        last_response_text = ''
         for i in range(self.retry_count + 1):
             response = self.session.get(url,
                                         params=params,
@@ -127,6 +133,7 @@ class _BaseReader(object):
             if response.status_code == requests.codes.ok:
                 return response
 
+            last_response_text = response.text.encode(response.encoding)
             time.sleep(pause)
 
             # Increase time between subsequent requests, per subclass.
@@ -134,14 +141,32 @@ class _BaseReader(object):
             # Get a new breadcrumb if necessary, in case ours is invalidated
             if isinstance(params, list) and 'crumb' in params:
                 params['crumb'] = self._get_crumb(self.retry_count)
+
+            # If our output error function returns True, exit the loop.
+            if self._output_error(response):
+                break
+
         if params is not None and len(params) > 0:
             url = url + "?" + urlencode(params)
-        raise RemoteDataError('Unable to read URL: {0}'.format(url))
+        msg = 'Unable to read URL: {0}'.format(url)
+        if last_response_text:
+            msg += '\nResponse Text:\n{0}'.format(last_response_text)
+
+        raise RemoteDataError(msg)
 
     def _get_crumb(self, *args):
         """ To be implemented by subclass """
         raise NotImplementedError("Subclass has not implemented method.")
 
+    def _output_error(self, out):
+        """If necessary, a service can implement an interpreter for any non-200
+         HTTP responses.
+
+        :param out: raw output from an HTTP request
+        :return: boolean
+        """
+        return False
+
     def _read_lines(self, out):
         rs = read_csv(out, index_col=0, parse_dates=True,
                       na_values=('-', 'null'))[::-1]
@@ -174,7 +199,7 @@ class _DailyBaseReader(_BaseReader):
         raise NotImplementedError
 
     def read(self):
-        """ read data """
+        """Read data"""
         # If a single symbol, (e.g., 'GOOG')
         if isinstance(self.symbols, (compat.string_types, int)):
             df = self._read_one_data(self.url,
